@@ -28,6 +28,11 @@
 #
 
 [ -z "$MAN_D" ] && MAN_D="/usr/man"
+[ -z "$LIB_D" ] && LIB_D="/lib"
+[ -z "$UDEV_D" ] && UDEV_D="$LIB_D/udev"
+[ -z "$SYSTEMD" ] && SYSTEMD="yes"
+[ -z "$SYSTEMD_UNIT_D" ] && SYSTEMD_UNIT_D="$LIB_D/systemd/system"
+[ -z "$TMPFILES_D" ] && TMPFILES_D="$LIB_D/tmpfiles.d"
 
 if [ -z "$ACPI" ] ; then
 	ACPI=auto
@@ -111,9 +116,9 @@ $INSTALL -d -m 755 "$DESTDIR/etc/laptop-mode/nolm-ac-stop"
 $INSTALL -d -m 755 "$DESTDIR/usr/share/laptop-mode-tools/modules"
 $INSTALL -d -m 755 "$DESTDIR/usr/share/laptop-mode-tools/module-helpers"
 $INSTALL -d -m 755 "$DESTDIR/etc/laptop-mode/conf.d"
-$INSTALL -d -m 755 "$DESTDIR/etc/laptop-mode/conf.d/board-specific"
 $INSTALL -d -m 755 "$DESTDIR/etc/laptop-mode/modules"
 $INSTALL -d -m 755 "$DESTDIR/usr/sbin"
+$INSTALL -d -m 755 "$DESTDIR/$UDEV_D/rules.d"
 $INSTALL -d -m 755 "$DESTDIR/$MAN_D/man8"
 
 ALREADY_EXISTED=0
@@ -195,14 +200,29 @@ if [ -f "$DESTDIR/usr/lib/pm-utils/sleep.d/99laptop-mode" ]; then
 fi
 
 # udev rule
-if ( ! $INSTALL -D -m 644 etc/rules/99-laptop-mode.rules "$DESTDIR/etc/udev/rules.d/99-laptop-mode.rules" ) ; then
-    echo "$0: Failed to install udev rule into /etc/udev/rules.d/ Installation failed."
+if ( ! $INSTALL -D -m 644 etc/rules/99-laptop-mode.rules "$DESTDIR/$UDEV_D/rules.d/99-laptop-mode.rules" ) ; then
+    echo "$0: Failed to install udev rule into $UDEV_D/rules.d/ Installation failed."
     exit 23
 fi
 
 # udev helper tool
-if ( ! $INSTALL -D -m 755 etc/rules/lmt-udev "$DESTDIR/lib/udev/lmt-udev" ) ; then
-	echo "$0: Failed to install udev helper tool into /lib/udev/ Installation failed."
+if ( ! $INSTALL -D -m 755 etc/rules/lmt-udev "$DESTDIR/$UDEV_D/lmt-udev" ) ; then
+	echo "$0: Failed to install udev helper tool into $UDEV_D Installation failed."
+fi
+
+if [ "${SYSTEMD}" = "yes" ]; then
+	$INSTALL -d -m 755 "$DESTDIR/$SYSTEMD_UNIT_D"
+	$INSTALL -d -m 755 "$DESTDIR/$TMPFILES_D"
+
+	# systemd service
+	if ( ! $INSTALL -D -m 644 etc/systemd/laptop-mode.service "$DESTDIR/$SYSTEMD_UNIT_D/laptop-mode.service" ) ; then
+		echo "$0: Failed to install systemd service into $SYSTEMD_UNIT_D Installation failed."
+	fi
+
+	# and systemd's tmpfiles.d
+	if ( ! $INSTALL -D -m 644 etc/systemd/laptop-mode.conf.tmpfiles "$DESTDIR/${TMPFILES_D}/laptop-mode.conf" ) ; then
+		echo "$0: Failed to install systemd tmpfiles into ${TMPFILES_D} Installation failed."
+	fi
 fi
 
 ACPI_DONE=0
